BAM - Blender Asset Manager's documentation
===========================================

Contents:

.. toctree::
   :maxdepth: 2

   manual/index.rst
   reference/index.rst
   install/index.rst
   design/planning.rst
   design/milestones.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

